@@ -50,8 +50,8 @@ getSeqSrcpaths <- function(seqnames, prefix="", suffix=".fa", seqs_srcdir=".")
     ans <- file.path(seqs_srcdir, srcfiles)
     is_OK <- file.exists(ans)
     if (!all(is_OK)) {
-        missing_files <- paste(ans[!is_OK], collapse=", ")
-        stop(missing_files, ": file(s) not found")
+        files_not_found <- paste(ans[!is_OK], collapse=", ")
+        stop("file(s) not found: ", files_not_found)
     }
     names(ans) <- seqnames
     ans
@@ -114,7 +114,8 @@ forgeSeqlengthsFile <- function(seqnames, prefix="", suffix=".fa",
     srcpath <- getSeqSrcpaths(name, prefix=prefix, suffix=suffix,
                               seqs_srcdir=seqs_srcdir)
     if (verbose)
-        cat("Loading FASTA file '", srcpath, "' in '", name, "' object ... ", sep="")
+        cat("Loading FASTA file '", srcpath, "' in '", name,
+            "' object ... ", sep="")
     seq <- readDNAStringSet(srcpath, "fasta")
     if (verbose)
         cat("DONE\n")
@@ -129,9 +130,9 @@ forgeSeqlengthsFile <- function(seqnames, prefix="", suffix=".fa",
     .saveObject(seq, name, destdir=seqs_destdir, verbose=verbose)
 }
 
-.forgeFastaRzFile <- function(seqnames, prefix, suffix,
-                              seqs_srcdir, seqs_destdir,
-                              mode, verbose=TRUE)
+.forgeFastaRzFileFromFastaFiles <- function(seqnames, prefix, suffix,
+                                            seqs_srcdir, seqs_destdir,
+                                            ondisk_seq_format, verbose=TRUE)
 {
     if (!is.character(seqnames))
         stop("'seqnames' must be a character vector")
@@ -141,7 +142,8 @@ forgeSeqlengthsFile <- function(seqnames, prefix="", suffix=".fa",
         srcpath <- getSeqSrcpaths(seqname, prefix=prefix, suffix=suffix,
                                   seqs_srcdir=seqs_srcdir)
         if (verbose)
-            cat("Loading '", seqname, "' sequence from FASTA file '", srcpath, "' ... ", sep="")
+            cat("Loading '", seqname, "' sequence from FASTA file '",
+                srcpath, "' ... ", sep="")
         seq <- readDNAStringSet(srcpath, "fasta")
         if (verbose)
             cat("DONE\n")
@@ -153,22 +155,25 @@ forgeSeqlengthsFile <- function(seqnames, prefix="", suffix=".fa",
             seq <- seq[1L]
         }
         if (verbose)
-            cat("Appending '", seqname, "' sequence to FASTA file '", dest_filepath, "' ... ", sep="")
+            cat("Appending '", seqname, "' sequence to FASTA file '",
+                dest_filepath, "' ... ", sep="")
         names(seq) <- seqname
-        writeXStringSet(seq, dest_filepath, append=TRUE, format="fasta", width=50L)
+        writeXStringSet(seq, dest_filepath, append=TRUE,
+                        format="fasta", width=50L)
         if (verbose)
             cat("DONE\n")
     }
 
-    if (mode == "fa") {
-        ## "fa" mode
+    ## Create the index.
+    if (ondisk_seq_format == "fa") {
+        ## "fa" format
         if (verbose)
             cat("Indexing FASTA file '", dest_filepath, "' ... ", sep="")
         indexFa(dest_filepath)
         if (verbose)
             cat("DONE\n")
     } else {
-        ## "fa.rz" mode
+        ## "fa.rz" format
         if (verbose)
             cat("Compressing FASTA file '", dest_filepath, "' ... ", sep="")
         farz_filepath <- sprintf("%s.rz", dest_filepath)
@@ -185,35 +190,139 @@ forgeSeqlengthsFile <- function(seqnames, prefix="", suffix=".fa",
     }
 }
 
-forgeSeqFiles <- function(seqnames, mseqnames=NULL, prefix="", suffix=".fa",
-                          seqs_srcdir=".", seqs_destdir=".",
-                          mode=c("rda", "fa", "fa.rz"), verbose=TRUE)
+.replace_non_ACGTN_with_N <- function(x)
 {
-    if (length(seqnames) == 0) {
+    af <- alphabetFrequency(x)
+    non_ACGTN <- setdiff(names(af), c(DNA_BASES, "N"))
+    if (sum(af[non_ACGTN]) == 0L)
+        return(x)
+    warning("DNA sequence contains letters not supported by UCSC twoBit ",
+            "format (the format\n  only supports A, C, G, T, and N). ",
+            "Replacing them with Ns.")
+    old <- paste(non_ACGTN, collapse="")
+    new <- paste(rep.int("N", length(non_ACGTN)), collapse="")
+    chartr(old, new, x)
+}
+
+.forgeTwobitFileFromFastaFiles <- function(seqnames, prefix, suffix,
+                                           seqs_srcdir, seqs_destdir,
+                                           verbose=TRUE)
+{
+    if (!is.character(seqnames))
+        stop("'seqnames' must be a character vector")
+    dest_filename <- "single_sequences.2bit"
+    dest_filepath <- file.path(seqs_destdir, dest_filename)
+    seqs <- setNames(vector(mode="list", length=length(seqnames)), seqnames)
+    for (seqname in seqnames) {
+        srcpath <- getSeqSrcpaths(seqname, prefix=prefix, suffix=suffix,
+                                  seqs_srcdir=seqs_srcdir)
+        if (verbose)
+            cat("Loading '", seqname, "' sequence from FASTA file '",
+                srcpath, "' ... ", sep="")
+        seq <- readDNAStringSet(srcpath, "fasta")
+        if (verbose)
+            cat("DONE\n")
+        if (length(seq) == 0L)
+            stop("file contains no DNA sequence")
+        if (length(seq) > 1L) {
+            warning("file contains ", length(seq), " sequences, ",
+                    "using the first sequence only")
+            seq <- seq[1L]
+        }
+        seq <- .replace_non_ACGTN_with_N(seq[[1L]])
+        seqs[[seqname]] <- seq
+    }
+    seqs <- DNAStringSet(seqs)
+    if (verbose)
+        cat("Writing all sequences to '", dest_filepath, "' ... ", sep="")
+    export(seqs, dest_filepath, format="2bit")
+    if (verbose)
+        cat("DONE\n")
+}
+
+.copySeqFile <- function(seqfile_name,
+                         seqs_srcdir, seqs_destdir,
+                         verbose=TRUE)
+{
+    src_filepath <- file.path(seqs_srcdir, seqfile_name)
+    if (!file.exists(src_filepath))
+        stop("File not found: ", src_filepath)
+    dest_filename <- "single_sequences.2bit"
+    dest_filepath <- file.path(seqs_destdir, dest_filename)
+    if (verbose)
+        cat("Copying '", src_filepath, "' to '", dest_filepath, "' ... ",
+            sep="")
+    if (!file.copy(src_filepath, dest_filepath,
+                   copy.mode=FALSE, copy.date=FALSE)) {
+        if (verbose)
+            stop("FAILED")
+        stop("Failed to copy '", src_filepath, "' to '", dest_filepath, "'")
+    }
+    if (verbose)
+        cat("DONE\n")
+}
+
+.subsetTwobitFile <- function(seqfile_name, seqnames,
+                              seqs_srcdir, seqs_destdir,
+                              verbose=verbose)
+{
+    src_filepath <- file.path(seqs_srcdir, seqfile_name)
+    dest_filename <- "single_sequences.2bit"
+    dest_filepath <- file.path(seqs_destdir, dest_filename)
+    if (verbose)
+        cat("Loading '", src_filepath, "' ... ", sep="")
+    seqs <- import(src_filepath)
+    if (verbose)
+        cat("DONE\n")
+    idx <- match(seqnames, names(seqs))
+    notfound_idx <- which(is.na(idx))
+    if (length(notfound_idx) != 0L)
+        stop("sequence(s) not found: ",
+             paste(seqnames[notfound_idx], collapse=", "))
+    seqs <- seqs[idx]
+    if (verbose)
+        cat("Writing sequences to '", dest_filepath, "' ... ", sep="")
+    export(seqs, dest_filepath, format="2bit")
+    if (verbose)
+        cat("DONE\n")
+}
+
+forgeSeqFiles <- function(seqnames, mseqnames=NULL,
+                          seqfile_name=NA, prefix="", suffix=".fa",
+                          seqs_srcdir=".", seqs_destdir=".",
+                          ondisk_seq_format=c("2bit", "rda", "fa.rz", "fa"),
+                          verbose=TRUE)
+{
+    if (length(seqnames) == 0L && is.na(seqfile_name))
         warning("'seqnames' is empty")
-    } else {
-        ## just for the side effect of checking the arguments
-        getSeqSrcpaths(seqnames, prefix=prefix, suffix=suffix,
-                       seqs_srcdir=seqs_srcdir)
-    }
-    if (length(mseqnames) != 0) {
-        if (!is.character(mseqnames))
-            stop("'mseqnames' must be a character vector (or NULL)")
-        ## just for the side effect of checking the arguments
-        getSeqSrcpaths(mseqnames, prefix=prefix, suffix=suffix,
-                       seqs_srcdir=seqs_srcdir)
-    }
+    if (!(length(mseqnames) == 0L || is.character(mseqnames)))
+        stop("'mseqnames' must be a character vector (or NULL)")
     if (!isSingleString(seqs_destdir))
         stop("'seqs_destdir' must be a single string")
-    mode <- match.arg(mode)
-    if (mode == "rda") {  # "rda" mode
+    ondisk_seq_format <- match.arg(ondisk_seq_format)
+    if (ondisk_seq_format == "rda") {  # "rda" format
         for (name in seqnames) {
             .forgeRdaSeqFile(name, prefix, suffix, seqs_srcdir, seqs_destdir,
                              is.single.seq=TRUE, verbose=verbose)
         }
-    } else {  # "fa" and "fa.rz" modes
-        .forgeFastaRzFile(seqnames, prefix, suffix, seqs_srcdir, seqs_destdir,
-                          mode, verbose=verbose)
+    } else if (ondisk_seq_format == "2bit") {  # "2bit" format
+        if (is.na(seqfile_name)) {
+            .forgeTwobitFileFromFastaFiles(seqnames, prefix, suffix,
+                                           seqs_srcdir, seqs_destdir,
+                                           verbose=verbose)
+        } else if (length(seqnames) == 0L) {
+            .copySeqFile(seqfile_name,
+                         seqs_srcdir, seqs_destdir,
+                         verbose=verbose)
+        } else {
+            .subsetTwobitFile(seqfile_name, seqnames,
+                              seqs_srcdir, seqs_destdir,
+                              verbose=verbose)
+        }
+    } else {  # "fa" and "fa.rz" formats
+        .forgeFastaRzFileFromFastaFiles(seqnames, prefix, suffix,
+                                        seqs_srcdir, seqs_destdir,
+                                        ondisk_seq_format, verbose=verbose)
     }
     for (name in mseqnames) {
         .forgeRdaSeqFile(name, prefix, suffix, seqs_srcdir, seqs_destdir,
@@ -333,7 +442,8 @@ forgeSeqFiles <- function(seqnames, mseqnames=NULL, prefix="", suffix=".fa",
 }
 
 .forgeMasksFile <- function(seqname, nmask_per_seq,
-                            seqs_destdir=".", mode=c("rda", "fa", "fa.rz"),
+                            seqs_destdir=".",
+                            ondisk_seq_format=c("2bit", "rda", "fa.rz", "fa"),
                             masks_srcdir=".", masks_destdir=".",
                             AGAPSfiles_type="gap", AGAPSfiles_name=NA,
                             AGAPSfiles_prefix="", AGAPSfiles_suffix="_gap.txt",
@@ -357,15 +467,21 @@ forgeSeqFiles <- function(seqnames, mseqnames=NULL, prefix="", suffix=".fa",
         stop("'masks_destdir' must be a single string")
 
     ## Load the sequence.
-    mode <- match.arg(mode)
-    if (mode == "rda") {  # "rda" mode
+    ondisk_seq_format <- match.arg(ondisk_seq_format)
+    if (ondisk_seq_format == "rda") {  # "rda" format
         seqfile <- file.path(seqs_destdir, paste(seqname, ".rda", sep=""))
         load(seqfile)
         seq <- get(seqname)
         remove(list=seqname)
-    } else {  # "fa" and "fa.rz" modes
+    } else if (ondisk_seq_format == "2bit") {  # "2bit" format
+        twobit_filename <- "single_sequences.2bit"
+        twobit_filepath <- file.path(seqs_destdir, twobit_filename)
+        twobitfile <- TwoBitFile(twobit_filepath)
+        which <- GRanges(seqname, IRanges(1L, seqlengths(twobitfile)[[seqname]]))
+        seq <- import(twobitfile, which=which)[[1L]]
+    } else {  # "fa" and "fa.rz" formats
         fa_filename <- "single_sequences.fa"
-        if (mode == "fa.rz")
+        if (ondisk_seq_format == "fa.rz")
             fa_filename <- paste0(fa_filename, ".rz")
         fa_filepath <- file.path(seqs_destdir, fa_filename)
         fafile <- FaFile(fa_filepath)
@@ -405,7 +521,8 @@ forgeSeqFiles <- function(seqnames, mseqnames=NULL, prefix="", suffix=".fa",
 }
 
 forgeMasksFiles <- function(seqnames, nmask_per_seq,
-                            seqs_destdir=".", mode=c("rda", "fa", "fa.rz"),
+                            seqs_destdir=".",
+                            ondisk_seq_format=c("2bit", "rda", "fa.rz", "fa"),
                             masks_srcdir=".", masks_destdir=".",
                             AGAPSfiles_type="gap", AGAPSfiles_name=NA,
                             AGAPSfiles_prefix="", AGAPSfiles_suffix="_gap.txt",
@@ -417,7 +534,8 @@ forgeMasksFiles <- function(seqnames, nmask_per_seq,
         warning("'seqnames' is empty")
     for (seqname in seqnames) {
         .forgeMasksFile(seqname, nmask_per_seq,
-                        seqs_destdir=seqs_destdir, mode=mode,
+                        seqs_destdir=seqs_destdir,
+                        ondisk_seq_format=ondisk_seq_format,
                         masks_srcdir=masks_srcdir, masks_destdir=masks_destdir,
                         AGAPSfiles_type=AGAPSfiles_type, AGAPSfiles_name=AGAPSfiles_name,
                         AGAPSfiles_prefix=AGAPSfiles_prefix, AGAPSfiles_suffix=AGAPSfiles_suffix,
@@ -441,9 +559,10 @@ setClass("BSgenomeDataPkgSeed",
         Version="character",
         Author="character",
         Maintainer="character",
+        Suggests="character",
         License="character",
         organism="character",
-        species="character",
+        common_name="character",
         provider="character",
         provider_version="character",
         release_date="character",
@@ -451,30 +570,33 @@ setClass("BSgenomeDataPkgSeed",
         source_url="character",
         organism_biocview="character",
         BSgenomeObjname="character",
-        seqnames="character",         # a single string containing R source code
-        circ_seqs="character",        # a single string containing R source code
-        mseqnames="character",        # a single string containing R source code
+        seqnames="character",        # a single string containing R source code
+        circ_seqs="character",       # a single string containing R source code
+        mseqnames="character",       # a single string containing R source code
         PkgDetails="character",
-        SrcDataFiles1="character",
-        SrcDataFiles2="character",
+        SrcDataFiles="character",
         PkgExamples="character",
+        seqfile_name="character",
         seqfiles_prefix="character",
-        seqfiles_suffix="character"
+        seqfiles_suffix="character",
+        ondisk_seq_format="character"
     ),
     prototype(
         Author="The Bioconductor Dev Team",
         Maintainer="Bioconductor Package Maintainer <maintainer@bioconductor.org>",
+        Suggests="",
         License="Artistic-2.0",
         source_url="-- information not available --",
-        seqnames="NULL",              # equivalent to "character(0)"
-        circ_seqs="NULL",             # equivalent to "character(0)"
-        mseqnames="NULL",             # equivalent to "character(0)"
+        seqnames="NULL",             # equivalent to "character(0)"
+        circ_seqs="NULL",            # equivalent to "character(0)"
+        mseqnames="NULL",            # equivalent to "character(0)"
         PkgDetails="",
-        SrcDataFiles1="-- information not available --",
-        SrcDataFiles2="",
+        SrcDataFiles="-- information not available --",
         PkgExamples="",
+        seqfile_name=NA_character_,
         seqfiles_prefix="",
-        seqfiles_suffix=".fa"
+        seqfiles_suffix=".fa",
+        ondisk_seq_format="2bit"
     )
 )   
 
@@ -487,13 +609,13 @@ setClass("MaskedBSgenomeDataPkgSeed",
         Author="character",
         Maintainer="character",
         RefPkgname="character",
+        Suggests="character",
         License="character",
         source_url="character",
         organism_biocview="character",
-        nmask_per_seq="integer",      # a single integer
+        nmask_per_seq="integer",     # a single integer
         PkgDetails="character",
-        SrcDataFiles1="character",
-        SrcDataFiles2="character",
+        SrcDataFiles="character",
         PkgExamples="character",
         AGAPSfiles_type="character",
         AGAPSfiles_name="character",
@@ -509,12 +631,12 @@ setClass("MaskedBSgenomeDataPkgSeed",
     prototype(
         Author="The Bioconductor Dev Team",
         Maintainer="Bioconductor Package Maintainer <maintainer@bioconductor.org>",
+        Suggests="",
         License="Artistic-2.0",
         source_url="-- information not available --",
         nmask_per_seq=0L,
         PkgDetails="",
-        SrcDataFiles1="-- information not available --",
-        SrcDataFiles2="",
+        SrcDataFiles="-- information not available --",
         PkgExamples="",
         AGAPSfiles_type="gap",
         AGAPSfiles_name=as.character(NA),
@@ -565,19 +687,19 @@ MaskedBSgenomeDataPkgSeed <- function(x)
 ###
 
 setGeneric("forgeBSgenomeDataPkg", signature="x",
-    function(x, seqs_srcdir=".", destdir=".",
-                mode=c("rda", "fa", "fa.rz"), verbose=TRUE)
+    function(x, seqs_srcdir=".", destdir=".", verbose=TRUE)
         standardGeneric("forgeBSgenomeDataPkg")
 )
 
 setMethod("forgeBSgenomeDataPkg", "BSgenomeDataPkgSeed",
-    function(x, seqs_srcdir=".", destdir=".",
-                mode=c("rda", "fa", "fa.rz"), verbose=TRUE)
+    function(x, seqs_srcdir=".", destdir=".", verbose=TRUE)
     {
-        require(Biobase) ||
-            stop("the Biobase package is required")
-        mode <- match.arg(mode)
-        template_path <- system.file("pkgtemplates", "BSgenome_datapkg", package="BSgenome")
+        ## The Biobase package is needed for createPackage().
+        if (!requireNamespace("Biobase", quietly=TRUE))
+            stop("Couldn't load the Biobase package. Please install ",
+                 "the Biobase\n  package and try again.")
+        template_path <- system.file("pkgtemplates", "BSgenome_datapkg",
+                                     package="BSgenome")
         BSgenome_version <- installed.packages()['BSgenome','Version']
         symvals <- list(
             PKGTITLE=x@Title,
@@ -586,9 +708,10 @@ setMethod("forgeBSgenomeDataPkg", "BSgenomeDataPkgSeed",
             AUTHOR=x@Author,
             MAINTAINER=x@Maintainer,
             BSGENOMEVERSION=BSgenome_version,
-            LIC=x@License,
+            SUGGESTS=x@Suggests,
+            LICENSE=x@License,
             ORGANISM=x@organism,
-            SPECIES=x@species,
+            COMMONNAME=x@common_name,
             PROVIDER=x@provider,
             PROVIDERVERSION=x@provider_version,
             RELEASEDATE=x@release_date,
@@ -596,12 +719,11 @@ setMethod("forgeBSgenomeDataPkg", "BSgenomeDataPkgSeed",
             SOURCEURL=x@source_url,
             ORGANISMBIOCVIEW=x@organism_biocview,
             BSGENOMEOBJNAME=x@BSgenomeObjname,
-            SEQNAMES=x@seqnames,
+            SEQNAMES=ifelse(is.na(x@seqfile_name), x@seqnames, "NULL"),
             CIRCSEQS=x@circ_seqs,
             MSEQNAMES=x@mseqnames,
             PKGDETAILS=x@PkgDetails,
-            SRCDATAFILES1=x@SrcDataFiles1,
-            SRCDATAFILES2=x@SrcDataFiles2,
+            SRCDATAFILES=x@SrcDataFiles,
             PKGEXAMPLES=x@PkgExamples
         )
         ## Should never happen
@@ -615,15 +737,13 @@ setMethod("forgeBSgenomeDataPkg", "BSgenomeDataPkgSeed",
             bad_syms <- paste(names(is_OK)[!is_OK], collapse=", ")
             stop("values for symbols ", bad_syms, " are not single strings")
         }
-        createPackage(x@Package, destdir, template_path, symvals)
+        Biobase::createPackage(x@Package, destdir, template_path, symvals)
         pkgdir <- file.path(destdir, x@Package)
-        ## Just to avoid codetools "no visible binding" NOTEs
-        .seqnames <- .mseqnames <- NULL
-        ## Sourcing this file will set the values of the '.seqnames' and
-        ## '.mseqnames' variables
-        source(file.path(pkgdir, "R", "zzz.R"), local=TRUE)
+
+        .seqnames <- eval(parse(text=x@seqnames))
+        .mseqnames <- eval(parse(text=x@mseqnames))
         seqs_destdir <- file.path(pkgdir, "inst", "extdata")
-        if (mode == "rda") {
+        if (x@ondisk_seq_format == "rda") {
             ## Forge the "seqlengths.rda" file
             forgeSeqlengthsFile(.seqnames,
                                 prefix=x@seqfiles_prefix,
@@ -632,25 +752,24 @@ setMethod("forgeBSgenomeDataPkg", "BSgenomeDataPkgSeed",
                                 seqs_destdir=seqs_destdir,
                                 verbose=verbose)
         }
-        ## Forge the sequence files (either "rda", "fa", or "fa.rz")
+        ## Forge the sequence files (either "2bit", "rda", "fa.rz", or "fa")
         forgeSeqFiles(.seqnames, mseqnames=.mseqnames,
+                      seqfile_name=x@seqfile_name,
                       prefix=x@seqfiles_prefix,
                       suffix=x@seqfiles_suffix,
                       seqs_srcdir=seqs_srcdir,
                       seqs_destdir=seqs_destdir,
-                      mode=mode,
+                      ondisk_seq_format=x@ondisk_seq_format,
                       verbose=verbose)
     }
 )
 
 setMethod("forgeBSgenomeDataPkg", "list",
-    function(x, seqs_srcdir=".", destdir=".",
-                mode=c("rda", "fa", "fa.rz"), verbose=TRUE)
+    function(x, seqs_srcdir=".", destdir=".", verbose=TRUE)
     {
         y <- BSgenomeDataPkgSeed(x)
-        forgeBSgenomeDataPkg(y,
-            seqs_srcdir=seqs_srcdir, destdir=destdir,
-            mode=mode, verbose=verbose)
+        forgeBSgenomeDataPkg(y, seqs_srcdir=seqs_srcdir, destdir=destdir,
+                                verbose=verbose)
     }
 )
 
@@ -714,8 +833,7 @@ read.dcf2 <- function(file, ...)
 }
 
 setMethod("forgeBSgenomeDataPkg", "character",
-    function(x, seqs_srcdir=".", destdir=".",
-                mode=c("rda", "fa", "fa.rz"), verbose=TRUE)
+    function(x, seqs_srcdir=".", destdir=".", verbose=TRUE)
     {
         y <- .readSeedFile(x, verbose=verbose)
         y <- as.list(y)
@@ -726,9 +844,8 @@ setMethod("forgeBSgenomeDataPkg", "character",
                      "'seqs_srcdir' field is missing in seed file")
         }
         y <- y[!(names(y) %in% "seqs_srcdir")]
-        forgeBSgenomeDataPkg(y,
-            seqs_srcdir=seqs_srcdir, destdir=destdir,
-            mode=mode, verbose=verbose)
+        forgeBSgenomeDataPkg(y, seqs_srcdir=seqs_srcdir, destdir=destdir,
+                                verbose=verbose)
     }
 )
 
@@ -745,8 +862,10 @@ setGeneric("forgeMaskedBSgenomeDataPkg", signature="x",
 setMethod("forgeMaskedBSgenomeDataPkg", "MaskedBSgenomeDataPkgSeed",
     function(x, masks_srcdir=".", destdir=".", verbose=TRUE)
     {
-        require(Biobase) ||
-            stop("the Biobase package is required")
+        ## The Biobase package is needed for createPackage().
+        if (!requireNamespace("Biobase", quietly=TRUE))
+            stop("Couldn't load the Biobase package. Please install ",
+                 "the Biobase\n  package and try again.")
         require(x@RefPkgname, character.only=TRUE) ||
             stop("the ", x@RefPkgname, " package is required")
         ref_envir <- as.environment(paste0("package:", x@RefPkgname))
@@ -761,9 +880,10 @@ setMethod("forgeMaskedBSgenomeDataPkg", "MaskedBSgenomeDataPkgSeed",
             MAINTAINER=x@Maintainer,
             BSGENOMEVERSION=BSgenome_version,
             REFPKGNAME=x@RefPkgname,
-            LIC=x@License,
+            SUGGESTS=x@Suggests,
+            LICENSE=x@License,
             ORGANISM=organism(ref_bsgenome),
-            SPECIES=species(ref_bsgenome),
+            COMMONNAME=commonName(ref_bsgenome),
             PROVIDER=provider(ref_bsgenome),
             PROVIDERVERSION=providerVersion(ref_bsgenome),
             RELEASEDATE=releaseDate(ref_bsgenome),
@@ -772,8 +892,7 @@ setMethod("forgeMaskedBSgenomeDataPkg", "MaskedBSgenomeDataPkgSeed",
             ORGANISMBIOCVIEW=x@organism_biocview,
             NMASKPERSEQ=as.character(x@nmask_per_seq),
             PKGDETAILS=x@PkgDetails,
-            SRCDATAFILES1=x@SrcDataFiles1,
-            SRCDATAFILES2=x@SrcDataFiles2,
+            SRCDATAFILES=x@SrcDataFiles,
             PKGEXAMPLES=x@PkgExamples
         )
         ## Should never happen
@@ -787,13 +906,13 @@ setMethod("forgeMaskedBSgenomeDataPkg", "MaskedBSgenomeDataPkgSeed",
             bad_syms <- paste(names(is_OK)[!is_OK], collapse=", ")
             stop("values for symbols ", bad_syms, " are not single strings")
         }
-        createPackage(x@Package, destdir, template_path, symvals)
+        Biobase::createPackage(x@Package, destdir, template_path, symvals)
         ## Forge the "*.masks.rda" files
         seqs_destdir <- dirname(seqlengthsFilepath(ref_bsgenome@single_sequences))
         pkgdir <- file.path(destdir, x@Package)
         masks_destdir <- file.path(pkgdir, "inst", "extdata")
         forgeMasksFiles(seqnames(ref_bsgenome), x@nmask_per_seq,
-                        seqs_destdir=seqs_destdir, mode="fa.rz",
+                        seqs_destdir=seqs_destdir, ondisk_seq_format="2bit",
                         masks_srcdir=masks_srcdir, masks_destdir=masks_destdir,
                         AGAPSfiles_type=x@AGAPSfiles_type, AGAPSfiles_name=x@AGAPSfiles_name,
                         AGAPSfiles_prefix=x@AGAPSfiles_prefix, AGAPSfiles_suffix=x@AGAPSfiles_suffix,
