@@ -77,10 +77,9 @@ setMethod("species", "SNPlocs",
     function(object)
     {
          msg <- wmsg("The \"species\" method for SNPlocs objects ",
-                     "is deprecated and should not be used anymore. ",
-                     "Please use commonName() instead of species() on ",
-                     "SNPlocs objects.")
-        .Deprecated(msg=msg)
+                     "is defunct. Please use commonName() instead ",
+                     "of species() on SNPlocs objects.")
+        .Defunct(msg=msg)
         commonName(object)
     }
 )
@@ -618,7 +617,7 @@ rowids2rowidx <- function(user_rowids, user_ids, x_rowids, ifnotfound)
     ifnotfound <- match.arg(ifnotfound)
     x_rowids <- .get_SNPlocs_data(x, "all_rsids")
     rowidx <- rowids2rowidx(user_rowids, ids, x_rowids, ifnotfound)
-    ans <- snpid2grange(x, rowidx[[1L]])
+    ans <- snpid2grange(x, rowidx[[2L]])
     mcols(ans)[ , "RefSNP_id"] <- rowidx[[2L]]
     ans
 }
